document.getElementById("Contents").innerHTML='\
    <ul><li><input type="checkbox" id="07"><label for="07">Macros and Scripting</label><ul>\
    <li><input type="checkbox" id="0701"><label for="0701">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
    <li><a target="_top" href="eo/text/sbasic/shared/main0601.html">Helpo de LibreOffice Basic</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01000000.html">Programming with LibreOffice Basic</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/00000002.html">LibreOffice BASIC glosaro</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01010210.html">Basics</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01020000.html">Sintakso</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01050000.html">Helpo de LibreOffice Basic</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01030100.html">IDE Overview</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01030200.html">The Basic Editor</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01050100.html">Watch Window</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/main0211.html">Makroa ilbreto</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/05060700.html">Makroo</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/vbasupport.html">Support for VBA Macros</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0702"><label for="0702">Referenco pri komandoj</label><ul>\
    <li><a target="_top" href="eo/text/sbasic/shared/01020300.html">Using Procedures and Functions</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01020500.html">Libraries, Modules and Dialogs</a></li>\
    <li><input type="checkbox" id="070202"><label for="070202">Funkcioj, ordonoj, kaj operacisimboloj</label><ul>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010000.html">Ekranaj en/eligaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020000.html">Dosieraj en/eligaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030000.html">Dataj kaj horaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03050000.html">Funkcioj por trakti erarojn</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03060000.html">Logikaj operacisimboloj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03070000.html">Matematikaj operacisimboloj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080000.html">Numeraj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090000.html">Regi programan ruladon</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100000.html">Variabloj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03040000.html">Basic Constants</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03110000.html">Komparaj operatoroj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120000.html">Ĉenoj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/special_vba_func.html">Exclusive VBA functions</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03130000.html">Aliaj komandoj</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070201"><label for="070201">Alfabeta listo de funkcioj, ordonoj, kaj operacisimboloj</label><ul>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080601.html">Abs Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03060100.html">AND Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03104200.html">Array Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120101.html">Asc Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120111.html">AscW Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080101.html">Atn Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03130100.html">Beep Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010301.html">Blue Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100100.html">CBool Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120105.html">CByte Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100050.html">CCur Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030116.html">CDateFromUnoDateTime Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030115.html">CDateToUnoDateTime Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030114.html">CDateFromUnoTime Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030113.html">CDateToUnoTime Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030112.html">CDateFromUnoDate Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030111.html">CDateToUnoDate Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030108.html">CDateFromIso Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030107.html">CDateToIso Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100300.html">CDate Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100400.html">CDbl Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100060.html">CDec Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100500.html">CInt Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100600.html">CLng Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100900.html">CSng Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03101000.html">CStr Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090401.html">Call Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020401.html">ChDir Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020402.html">ChDrive Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090402.html">Choose Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120102.html">Chr Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120112.html">ChrW Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020101.html">Close Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100700.html">Const Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120313.html">ConvertFromURL Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120312.html">ConvertToURL Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080102.html">Cos Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03132400.html">CreateObject Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131800.html">CreateUnoDialog Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03132000.html">CreateUnoListener Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131600.html">CreateUnoService Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131500.html">CreateUnoStruct Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03132300.html">CreateUnoValue Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020403.html">CurDir Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100070.html">CVar Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03100080.html">CVErr Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030110.html">DateAdd Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030120.html">DateDiff Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030130.html">DatePart Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030101.html">DateSerial Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030102.html">DateValue Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030301.html">Date Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030103.html">Day Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140000.html">DDB Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090403.html">Declare Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03101100.html">DefBool Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03101300.html">DefDate Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03101400.html">DefDbl Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03101500.html">DefInt Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03101600.html">DefLng Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03101700.html">DefObj Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102000.html">DefVar Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03104300.html">DimArray Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102100.html">Dim Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020404.html">Dir Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090201.html">Do...Loop Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090404.html">End Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03130800.html">Environ Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020301.html">Eof Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03104600.html">EqualUnoObjects Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03060200.html">Eqv Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03050100.html">Erl Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03050200.html">Err Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03050300.html">Error Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03050000.html">Funkcioj por trakti erarojn</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090412.html">Exit Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080201.html">Exp Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020405.html">FileAttr Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020406.html">FileCopy Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020407.html">FileDateTime Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020415.html">FileExists Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020408.html">FileLen Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103800.html">FindObject Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103900.html">FindPropertyObject Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080501.html">Fix Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120301.html">Format Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090406.html">Function Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090400.html">Pluaj ordonoj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140001.html">FV Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080300.html">Generi hazardajn numerojn</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020409.html">GetAttr Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03132500.html">GetDefaultContext Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03132100.html">GetGuiType Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131700.html">GetProcessServiceManager Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131000.html">GetSolarVersion Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03130700.html">GetSystemTicks Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020201.html">Get Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090301.html">GoSub...Return Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090302.html">GoTo Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010302.html">Green Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03104400.html">HasUnoInterfaces Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080801.html">Hex Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030201.html">Hour Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090103.html">IIf Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090101.html">If...Then...Else Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03060300.html">Imp Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120401.html">InStr Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120411.html">InStrRev Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03160000.html">Input Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010201.html">InputBox Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020202.html">Input# Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080502.html">Int Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140002.html">IPmt Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140003.html">IRR Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102200.html">IsArray Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102300.html">IsDate Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102400.html">IsEmpty Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03104000.html">IsMissing function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102600.html">IsNull Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102700.html">IsNumeric Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102800.html">IsObject Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03104500.html">IsUnoStruct Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120315.html">Join Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020410.html">Kill Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102900.html">LBound Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120302.html">LCase Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120304.html">LSet Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120305.html">LTrim Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120303.html">Left Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120402.html">Len Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103100.html">Let Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020203.html">Line Input # Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020302.html">Loc Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020303.html">Lof Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080202.html">Log Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120306.html">Mid Function, Mid Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030202.html">Minute Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140004.html">MIRR Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020411.html">MkDir Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03070600.html">Mod Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030104.html">Month Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03150002.html">MonthName Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010102.html">MsgBox Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010101.html">MsgBox Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020412.html">Name Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03060400.html">Not Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030203.html">Now Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140005.html">NPer Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140006.html">NPV Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080000.html">Numeraj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080802.html">Oct Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03050500.html">On Error GoTo ... Resume Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090303.html">On...GoSub Statement; On...GoTo Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020103.html">Open Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103200.html">Option Base Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103300.html">Option Explicit Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103350.html">Option VBASupport Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03104100.html">Optional (in Function Statement)</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03060500.html">Or Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140007.html">Pmt Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140008.html">PPmt Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140009.html">PV Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010103.html">Print Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103400.html">Public Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020204.html">Put Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010304.html">QBColor Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140010.html">Rate Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010305.html">RGB Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120308.html">RSet Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120309.html">RTrim Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080301.html">Randomize Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03102101.html">ReDim Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03010303.html">Red Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090407.html">Rem Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020104.html">Reset Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120307.html">Right Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020413.html">RmDir Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080302.html">Rnd Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03170000.html">Round Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030204.html">Second Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020304.html">Seek Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020305.html">Seek Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090102.html">Select...Case Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020414.html">SetAttr Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103700.html">Set Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080701.html">Sgn Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03130500.html">Shell Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080103.html">Sin Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140011.html">SLN Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120201.html">Space Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120314.html">Split Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080401.html">Sqr Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080400.html">Kalkuli kvadratan radikon</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103500.html">Static Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090408.html">Stop Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120403.html">StrComp Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120103.html">Str Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120412.html">StrReverse Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120202.html">String Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090409.html">Sub Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090410.html">Switch Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03140012.html">SYD Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080104.html">Tan Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030205.html">TimeSerial Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030206.html">TimeValue Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030302.html">Time Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030303.html">Timer Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03080100.html">Trigonometriaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120311.html">Trim Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131300.html">TwipsPerPixelX Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03131400.html">TwipsPerPixelY Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090413.html">Type Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103600.html">TypeName Function; VarType Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03103000.html">UBound Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120310.html">UCase Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03120104.html">Val Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03130600.html">Wait Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030105.html">WeekDay Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03150001.html">WeekdayName Function [VBA]</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090203.html">While...Wend Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03090411.html">With Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03020205.html">Write Statement</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03060600.html">XOR Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03030106.html">Year Function</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03070100.html">"-" Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03070200.html">"*" Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03070300.html">"+" Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070205"><label for="070205">Specialaj bazaj bibliotekoj</label><ul>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_formwizard.html">FORMWIZARD Library</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_gimmicks.html">GIMMICKS Library</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_schedule.html">SCHEDULE Library</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_script.html">SCRIPTBINDINGLIBRARY Library</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/03/lib_template.html">TEMPLATE Library</a></li>\
			</ul></li>\
                    </ul></li>\
    <li><input type="checkbox" id="0703"><label for="0703">Manlibroj</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/macro_recording.html">Registri makroon</a></li>\
    <li><a target="_top" href="eo/text/sbasic/guide/control_properties.html">Ŝanĝado de Atributoj de Regiloj en la Dialoga Redaktilo</a></li>\
    <li><a target="_top" href="eo/text/sbasic/guide/insert_control.html">Kreado de Regiloj en la Dialoga Redaktilo</a></li>\
    <li><a target="_top" href="eo/text/sbasic/guide/sample_code.html">Programadaj Ekzemploj por Regiloj en la Dialoga Redaktilo</a></li>\
    <li><a target="_top" href="eo/text/sbasic/guide/show_dialog.html">Malfermi dialogon per programa kodo</a></li>\
    <li><a target="_top" href="eo/text/sbasic/guide/create_dialog.html">Krei Basic-dialogon</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01030400.html">Organizing Libraries and Modules</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01020100.html">Ĉena variablo</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01020200.html">Using Objects</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01030300.html">Debugging a Basic Program</a></li>\
    <li><a target="_top" href="eo/text/sbasic/shared/01040000.html">Event-Driven Macros</a></li>\
    <li><a target="_top" href="eo/text/sbasic/guide/access2base.html">Access2Base</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="08"><label for="08">Spreadsheets (Calc)</label><ul>\
    <li><input type="checkbox" id="0801"><label for="0801">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
    <li><a target="_top" href="eo/text/scalc/main0000.html">Bonvenon al la Helpo de LibreOffice Tabelilo</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0503.html">Ebloj de LibreOffice Tabelilo</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/keyboard.html">Shortcut Keys (LibreOffice Calc Accessibility)</a></li>\
    <li><a target="_top" href="eo/text/scalc/04/01020000.html">Fulmoklavoj por kalkultabeloj</a></li>\
    <li><a target="_top" href="eo/text/scalc/05/02140000.html">Erarkodoj en LibreOffice-Tabelilo</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060112.html">Kromprogramo por programi en LibreOffice Calc</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/main.html">Instructions for Using LibreOffice Calc</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0802"><label for="0802">Referenco pri ordonoj kaj menuoj</label><ul>\
    <li><input type="checkbox" id="080201"><label for="080201">Menuoj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/main0100.html">Menuoj</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0101.html">Dosiero</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0102.html">Redakti</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0103.html">Vido</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0104.html">Enmeti</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0105.html">Formato</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0116.html">Folio</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0112.html">Datumoj</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0106.html">Iloj</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0107.html">Fenestro</a></li>\
    <li><a target="_top" href="eo/text/shared/main0108.html">Helpo</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="080202"><label for="080202">Ilobretoj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/main0200.html">Ilobretoj</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0202.html">Formata breto</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0203.html">Breto de desegnaj objektaj atributoj</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0205.html">Tekstformata breto</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0206.html">Formula breto</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0208.html">Stata breto</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0210.html">Breto Aspekto de paĝo</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0214.html">Bilda breto</a></li>\
    <li><a target="_top" href="eo/text/scalc/main0218.html">Breto Iloj</a></li>\
    <li><a target="_top" href="eo/text/shared/main0201.html">Ĝenerala breto</a></li>\
    <li><a target="_top" href="eo/text/shared/main0212.html">Ilbreto Tabelaj datumoj</a></li>\
    <li><a target="_top" href="eo/text/shared/main0213.html">Ilbreto por navigi formularojn</a></li>\
    <li><a target="_top" href="eo/text/shared/main0214.html">Ilbreto Fasoni informpeton</a></li>\
    <li><a target="_top" href="eo/text/shared/main0226.html">Ilbreto por aranĝi formularon</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0803"><label for="0803">Funkcioj, tipoj kaj operacisimboloj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/01/04060000.html">Funkcia asistanto</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060100.html">Funkcioj laŭ Kategorio</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060107.html">Tabelaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060120.html">Bit Operation Functions</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060101.html">Datumbazaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060102.html">Dataj kaj horaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060103.html">Financaj funkcioj, Parto Unua</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060119.html">Financaj Funkcioj - Parto Dua</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060118.html">Financaj funkcioj, Parto Tria</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060104.html">Informaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060105.html">Logikaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060106.html">Matematikaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060108.html">Statistikaj Funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060181.html">Statistikaj Funkcioj, Parto Unua</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060182.html">Statistikaj Funkcioj - Parto Dua</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060183.html">Statistikaj Funkcioj - Parto Tria</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060184.html">Statistikaj Funkcioj - Parto Kvara</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060185.html">Statistikaj funkcioj, Parto Kvina</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060109.html">Kalkultabelaj Funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060110.html">Tekstaj funkcioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060111.html">Add-in Functions</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060115.html">Kromprogramaj Funkcioj, Listo de Analizaj Funkcioj Parto Unu</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060116.html">Kromprogramaj Funkcioj, Listo de Analizaj Funkcioj Parto Du</a></li>\
    <li><a target="_top" href="eo/text/scalc/01/04060199.html">Operatoroj en LibreOffice Calc</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/userdefined_function.html">User-Defined Functions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0804"><label for="0804">Ŝargi, konservi, importi kaj eksporti</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/webquery.html">Inserting External Data in Table (WebQuery)</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/html_doc.html">Saving and Opening Sheets in HTML</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/csv_formula.html">Importing and Exporting Text Files</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0805"><label for="0805">Aranĝado</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/text_rotate.html">Turnado de teksto</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/text_wrap.html">Writing Multi-line Text</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/text_numbers.html">Formatting Numbers as Text</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/super_subscript.html">Text Superscript / Subscript</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/row_height.html">Changing Row Height or Column Width</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cellstyle_conditional.html">Applying Conditional Formatting</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cellstyle_minusvalue.html">Highlighting Negative Numbers</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cellstyle_by_formula.html">Assigning Formats by Formula</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/integer_leading_zero.html">Entering a Number with Leading Zeros</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/format_table.html">Formatting Spreadsheets</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/format_value.html">Formatting Numbers With Decimals</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/value_with_name.html">Naming Cells</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/table_rotate.html">Rotating Tables (Transposing)</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/rename_table.html">Renaming Sheets</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/year2000.html">19xx/20xx Jaroj</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/rounding_numbers.html">Using Rounded Off Numbers</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/currency_format.html">Cells in Currency Format</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/autoformat.html">Uzi aŭtomatan formaton por tabeloj</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/note_insert.html">Inserting and Editing Comments</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/design.html">Elektado de etosoj por folioj</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/fraction_enter.html">Entering Fractions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0806"><label for="0806">Filtri kaj ordigi</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/filters.html">Applying Filters</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/specialfilter.html">Filter: Applying Advanced Filters</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/autofilter.html">Apliki aŭtomatan filtrilon</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/sorted_list.html">Applying Sort Lists</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0807"><label for="0807">Presado</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/print_title_row.html">Printing Rows or Columns on Every Page</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/print_landscape.html">Printing Sheets in Landscape Format</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/print_details.html">Printing Sheet Details</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/print_exact.html">Defining Number of Pages for Printing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0808"><label for="0808">Datumaj ampleksoj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/database_define.html">Defining Database Ranges</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/database_filter.html">Filtering Cell Ranges</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/database_sort.html">Sorting Data</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0809"><label for="0809">Pivota tabelo</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/datapilot.html">PivotTabelo</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/datapilot_createtable.html">Krei pivottabelojn</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/datapilot_deletetable.html">Forigi enhavon</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/datapilot_edittable.html">Pivottabeloj</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/datapilot_filtertable.html">Filtri pivottabelojn</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/datapilot_tipps.html">Elekti datumbazamplekson</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/datapilot_updatetable.html">Ĝisdatigi pivottabelojn</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="08091"><label for="08091">Pivota diagramo</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/pivotchart_filter.html">Filtering Pivot Charts</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/pivotchart_update.html">Pivot Chart Update</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/pivotchart_delete.html">Deleting Pivot Charts</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="0810"><label for="0810">Scenaroj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/scenario.html">Using Scenarios</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0811"><label for="0811">Referencoj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/relativ_absolut_ref.html">Addresses and References, Absolute and Relative</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cellreferences.html">Referencing a Cell in Another Document</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cellreferences_url.html">References to Other Sheets and Referencing URLs</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cellreference_dragdrop.html">Referencing Cells by Drag-and-Drop</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/address_auto.html">Rekonado de nomoj kiel titolado</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0812"><label for="0812">Vidi, elekti, kopii</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/table_view.html">Changing Table Views</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/formula_value.html">Displaying Formulas or Values</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/line_fix.html">Freezing Rows or Columns as Headers</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/multi_tables.html">Navigating Through Sheets Tabs</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/edit_multitables.html">Copying to Multiple Sheets</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cellcopy.html">Only Copy Visible Cells</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/mark_cells.html">Selecting Multiple Cells</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0813"><label for="0813">Formuloj kaj kalkuloj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/formulas.html">Calculating With Formulas</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/formula_copy.html">Copying Formulas</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/formula_enter.html">Entering Formulas</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/formula_value.html">Displaying Formulas or Values</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/calculate.html">Calculating in Spreadsheets</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/calc_date.html">Calculating With Dates and Times</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/calc_series.html">Automatically Calculating Series</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/calc_timevalues.html">Calculating Time Differences</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/matrixformula.html">Entering Matrix Formulas</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0814"><label for="0814">Protekto</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/cell_protect.html">Protecting Cells from Changes</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/cell_unprotect.html">Unprotecting Cells</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0815"><label for="0815">Diversaj</label><ul>\
    <li><a target="_top" href="eo/text/scalc/guide/auto_off.html">Malŝalti aŭtomatajn ŝanĝojn</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/consolidate.html">Consolidating Data</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/goalseek.html">Applying Goal Seek</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/multioperation.html">Applying Multiple Operations</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/multitables.html">Applying Multiple Sheets</a></li>\
    <li><a target="_top" href="eo/text/scalc/guide/validity.html">Validity of Cell Contents</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="05"><label for="05">Diagramoj</label><ul>\
    <li><input type="checkbox" id="0501"><label for="0501">Ĝenerala informo</label><ul>\
    <li><a target="_top" href="eo/text/schart/main0000.html">Diagramoj en LibreOffice</a></li>\
    <li><a target="_top" href="eo/text/schart/main0503.html">Diagramaj ebloj de LibreOffice</a></li>\
    <li><a target="_top" href="eo/text/schart/04/01020000.html">Fulmoklavoj por Diagramoj</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice Installation</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/ms_doctypes.html">Ŝanĝi la asocion de tipoj de Microsoft Office-dokumentoj</a></li>\
    <li><a target="_top" href="eo/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="10"><label for="10">Oftaj helpaj temoj</label><ul>\
    <li><input type="checkbox" id="1001"><label for="1001">Ĝenerala informo</label><ul>\
    <li><a target="_top" href="eo/text/shared/main0400.html">Fulmklavoj</a></li>\
    <li><a target="_top" href="eo/text/shared/00/00000005.html">Ĝenerala glosaro</a></li>\
    <li><a target="_top" href="eo/text/shared/00/00000002.html">Glosaro pri interretaj terminoj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/accessibility.html">Alirebleco en LibreOffice</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/keyboard.html">Shortcuts (LibreOffice Accessibility)</a></li>\
    <li><a target="_top" href="eo/text/shared/04/01010000.html">General Shortcut Keys in LibreOffice</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/version_number.html">Versions and Build Numbers</a></li>\
</ul></li>\
    <li><input type="checkbox" id="1002"><label for="1002">LibreOffice kaj Microsoft Office</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/ms_user.html">Kompari inter Microsoft Office kaj LibreOffice-terminoj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/microsoft_terms.html">Kompari inter Microsoft Office kaj LibreOffice-terminoj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/ms_import_export_limitations.html">Pri konverti dokumentojn de Microsift Office</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/ms_doctypes.html">Ŝanĝi la asocion de tipoj de Microsoft Office-dokumentoj</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1004"><label for="1004">LibreOffice-ebloj</label><ul>\
    <li><a target="_top" href="eo/text/shared/optionen/01000000.html">Agordaro</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010100.html">Datumoj de uzanto</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010200.html">Ĝenerala</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010300.html">Vojprefiksoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010400.html">Skribhelpoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010600.html">Ĝenerala</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010700.html">Tiparoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010800.html">Vido</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01010900.html">Presagordaĵoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01012000.html">Application Colors</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01013000.html">Alireblo</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/java.html">Advanced</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/expertconfig.html">Expert Configuration</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/persona_firefox.html">Personalization</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/BasicIDE.html">Basic IDE</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/opencl.html">Open CL</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01020000.html">Load/Save options</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01030000.html">Interreta Agordaro</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01040000.html">Agordaĵoj de Teksta Dokumento</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01050000.html">Agordaĵoj de HTML-a Dokumento</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01060000.html">Kalkultabela Agordaĵoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01070000.html">Prezentaĵaj agordaĵoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01080000.html">Desegnaj Agordaĵoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01090000.html">Formulo</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01110000.html">Diagramaj Agordaĵoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01130100.html">VBA-atributoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01130200.html">Microsoft Office</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01140000.html">Lingvoj</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01150000.html">Language Setting Options</a></li>\
    <li><a target="_top" href="eo/text/shared/optionen/01160000.html">Data sources options</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1005"><label for="1005">Asistantoj</label><ul>\
    <li><a target="_top" href="eo/text/shared/autopi/01000000.html">Wizard</a></li>\
    <li><input type="checkbox" id="100501"><label for="100501">Letera Asistanto</label><ul>\
    <li><a target="_top" href="eo/text/shared/autopi/01010000.html">Letera asistanto</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100502"><label for="100502">Faksa Asistanto</label><ul>\
    <li><a target="_top" href="eo/text/shared/autopi/01020000.html">Faksa asistanto</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100504"><label for="100504">Tagorda Asistanto</label><ul>\
    <li><a target="_top" href="eo/text/shared/autopi/01040000.html">Tagorda asistanto</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100506"><label for="100506">HTML-eksporta Asistanto</label><ul>\
    <li><a target="_top" href="eo/text/shared/autopi/01110000.html">Eksporti HTML-on</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100510"><label for="100510">Asistanto pri konverti dokumentojn</label><ul>\
    <li><a target="_top" href="eo/text/shared/autopi/01130000.html">Dokumenta konvertilo</a></li>\
			</ul></li>\
    <li><a target="_top" href="eo/text/shared/autopi/01150000.html">Euro Converter Wizard</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1006"><label for="1006">Agordado de LibreOffice</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/configure_overview.html">Agordi je LibreOffice</a></li>\
    <li><a target="_top" href="eo/text/shared/01/packagemanager.html">Mastrumilo de aldonaĵoj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/flat_icons.html">Ŝanĝi bildsimbolajn vidojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/edit_symbolbar.html">Adding Buttons to Toolbars</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/workfolder.html">Changing Your Working Directory</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/standard_template.html">Changing Default Templates</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_addressbook.html">Registering an Address Book</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/formfields.html">Inserting and Editing Buttons</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1007"><label for="1007">Labori per la uzinterfaco</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/navigator_setcursor.html">Navigation to Quickly Reach Objects</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/navigator.html">Navigator for Document Overview</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/autohide.html">Vidigi, endokigi kaj kaŝi fenestrojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/navpane_on.html">Showing Navigation Pane of the Help</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/textmode_change.html">Switching Between Insert Mode and Overwrite Mode</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/floating_toolbar.html">Using Toolbars</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="10071"><label for="10071">Ciferecaj subskriboj</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/digital_signatures.html">About Digital Signatures</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/digitalsign_send.html">Applying Digital Signatures</a></li>\
    <li><a target="_top" href="eo/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
    <li><a target="_top" href="eo/text/shared/01/signexistingpdf.html">Signing Existing PDF</a></li>\
    <li><a target="_top" href="eo/text/swriter/01/addsignatureline.html">Adding Signature Line in Text Documents</a></li>\
    <li><a target="_top" href="eo/text/swriter/01/signsignatureline.html">Signing the Signature Line</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="1008"><label for="1008">Presi, faksi, sendi</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/labels_database.html">Printing Address Labels</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/print_blackwhite.html">Printing in Black and White</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/email.html">Sending Documents as E-mail</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/fax.html">Sending Faxes and Configuring LibreOffice for Faxing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1009"><label for="1009">Ŝovi kaj demeti</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop.html">Dragging and Dropping Within a LibreOffice Document</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/dragdroptext.html">Movi kaj kopii tekston en dokumentoj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_table.html">Copying Spreadsheet Areas to Text Documents</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_graphic.html">Copying Graphics Between Documents</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_fromgallery.html">Aldoni grafikojn al la galerio</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_beamer.html">Drag-and-Drop With the Data Source View</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1010"><label for="1010">Kopii kaj alglui</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/copy_drawfunctions.html">Kopii desegnajn objektojn en aliajn dokumentojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_graphic.html">Copying Graphics Between Documents</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_fromgallery.html">Aldoni grafikojn al la galerio</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_table.html">Copying Spreadsheet Areas to Text Documents</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1012"><label for="1012">Diagramoj</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/chart_insert.html">Enmeti diagramojn</a></li>\
    <li><a target="_top" href="eo/text/schart/main0000.html">Diagramoj en LibreOffice</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1013"><label for="1013">Ŝargi, konservi, importi kaj eksporti</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/doc_open.html">Konservi dokumentojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/import_ms.html">Opening documents saved in other formats</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/doc_save.html">Konservi dokumentojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/doc_autosave.html">Saving Documents Automatically</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/export_ms.html">Saving Documents in Other Formats</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_dbase2office.html">Importing and Exporting Data in Text Format</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1014"><label for="1014">Ligiloj kaj referencoj</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/hyperlink_insert.html">Enmeti hiperligilojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/hyperlink_rel_abs.html">Relative and Absolute Links</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/hyperlink_edit.html">Redakti hiperligilojn</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1015"><label for="1015">Mastrumi dokumentajn versiojn</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/redlining_doccompare.html">Kompari versiojn de dokumento</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/redlining_docmerge.html">Kunfandi versiojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/redlining_enter.html">Registri ŝanĝojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/redlining.html">Recording and Displaying Changes</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/redlining_accept.html">Akcepti aŭ malakcepti ŝanĝojn.</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/redlining_versions.html">Mastrumi versiojn</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1016"><label for="1016">Etikedoj kaj nomkartoj</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/labels.html">Creating and Printing Labels and Business Cards</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1018"><label for="1018">Enigi eksterajn datumojn</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/copytable2application.html">Enmeti datumojn el kalkultabeloj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/copytext2application.html">Enmeti datumojn el tekstaj dokumentoj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/insert_bitmap.html">Inserting, Editing, Saving Bitmaps</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/dragdrop_gallery.html">Aldoni grafikojn al la galerio</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1019"><label for="1019">Aŭtomataj funkcioj</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/autocorr_url.html">Malŝalti aŭtomatan URL-rekonadon</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1020"><label for="1020">Serĉi kaj anstataŭigi</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/data_search2.html">Searching With a Form Filter</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_search.html">Searching Tables and Form Documents</a></li>\
    <li><a target="_top" href="eo/text/shared/01/02100001.html">List of Regular Expressions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1021"><label for="1021">Manlibroj</label><ul>\
    <li><a target="_top" href="eo/text/shared/guide/linestyles.html">Agordi liniajn stilojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/text_color.html">Changing the Color of Text</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/change_title.html">Ŝanĝi la titolon de dokumento</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/round_corner.html">Creating Round Corners</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/background.html">Agordi fonajn kolorojn aŭ fonajn grafikojn.</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/lineend_define.html">Agordi liniajn stilojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/linestyle_define.html">Agordi liniajn stilojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/insert_graphic_drawit.html">Editing Graphic Objects</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/line_intext.html">Drawing Lines in Text</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/aaa_start.html">Unuaj paŝoj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/gallery_insert.html">Inserting Objects From the Gallery</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/space_hyphen.html">Inserting Non-breaking Spaces, Hyphens and Soft Hyphens</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/insert_specialchar.html">Inserting Special Characters</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/tabs.html">Inserting and Editing Tab Stops</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/protection.html">Protecting Content in LibreOffice</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/redlining_protect.html">Protecting Records</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/pageformat_max.html">Elekti la maksimuman preseblan areon en paĝo.</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/measurement_units.html">Selecting Measurement Units</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/language_select.html">Selecting the Document Language</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_tabledefine.html">Tabela Skizo</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/numbering_stop.html">Turning off Bullets and Numbering for Individual Paragraphs</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="09"><label for="09">Database Functionality (Base)</label><ul>\
    <li><input type="checkbox" id="0901"><label for="0901">Ĝenerala informo</label><ul>\
    <li><a target="_top" href="eo/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/database_main.html">Database Overview</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_new.html">Creating a New Database</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_tables.html">Labori per tabeloj</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_queries.html">Prilabori informpetojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_forms.html">Prilabori informpetojn</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_reports.html">Finado de Eraroraporto</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_register.html">Registering and Deleting a Database</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_im_export.html">Importing and Exporting Data in Base</a></li>\
    <li><a target="_top" href="eo/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="04"><label for="04">Presentations and Drawings (Impress/Draw)</label><ul>\
    <li><input type="checkbox" id="0401"><label for="0401">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
    <li><a target="_top" href="eo/text/simpress/main0000.html">Bonvenon al la helpo de LibreOffice-Prezentilo</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0000.html">Bonvenon al la helpo de LibreOffice-Desegnilo</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0503.html">Ebloj de LibreOffice-Prezentilo</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0503.html">Ebloj de LibreOffice-Desegnilo</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/keyboard.html">Using Shortcut Keys in LibreOffice Impress</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/keyboard.html">Shortcut Keys for Drawing Objects</a></li>\
    <li><a target="_top" href="eo/text/simpress/04/01020000.html">Fulmoklavoj por LibreOffice Prezentilo</a></li>\
    <li><a target="_top" href="eo/text/simpress/04/presenter.html">Presenter Console Keyboard Shortcuts</a></li>\
    <li><a target="_top" href="eo/text/sdraw/04/01020000.html">Fulmoklavoj por Desegnaĵoj</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/main.html">Instructions for Using LibreOffice Impress</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/main.html">Instructions for Using LibreOffice Draw</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0402"><label for="0402">Referenco pri ordonoj kaj menuoj</label><ul>\
    <li><input type="checkbox" id="040201"><label for="040201">Prezentaĵoj (LibreOffice-Prezentilo)</label><ul>\
    <li><input type="checkbox" id="04020101"><label for="04020101">Menuoj</label><ul>\
    <li><a target="_top" href="eo/text/simpress/main0100.html">Menuoj</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0101.html">Dosiero</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0102.html">Redakti</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0103.html">Vido</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0104.html">Enmeti</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0105.html">Formato</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0117.html">Lumbildo</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0114.html">Vidigu prezentaĵon</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0106.html">Iloj</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0107.html">Fenestro</a></li>\
    <li><a target="_top" href="eo/text/shared/main0108.html">Helpo</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020102"><label for="04020102">Ilobretoj</label><ul>\
    <li><a target="_top" href="eo/text/simpress/main0200.html">Ilobretoj</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0202.html">Linia kaj pleniga breto</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0203.html">Tekstformata breto</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0204.html">Lumbildvida breto</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0206.html">Stata breto</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0209.html">Mezuriloj</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0210.html">Desegna breto</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0211.html">Resuma breto</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0212.html">Ilbreto ordigi lumbildojn</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0213.html">Agorda breto</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0214.html">Bilda breto</a></li>\
    <li><a target="_top" href="eo/text/shared/main0201.html">Ĝenerala breto</a></li>\
    <li><a target="_top" href="eo/text/shared/main0213.html">Ilbreto por navigi formularojn</a></li>\
    <li><a target="_top" href="eo/text/shared/main0226.html">Ilbreto por aranĝi formularon</a></li>\
    <li><a target="_top" href="eo/text/shared/main0227.html">Ilbreto Redakti punktojn</a></li>\
                 </ul></li>\
             </ul></li>\
    <li><input type="checkbox" id="040202"><label for="040202">Desegnaĵoj (LibreOffice-Desegnilo)</label><ul>\
    <li><input type="checkbox" id="04020201"><label for="04020201">Menuoj</label><ul>\
    <li><a target="_top" href="eo/text/sdraw/main0100.html">Menuoj</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0101.html">Dosiero</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0102.html">Redakti</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0103.html">Vido</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0104.html">Enmeti</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0105.html">Formato</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0106.html">Iloj</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0113.html">Modifi</a></li>\
    <li><a target="_top" href="eo/text/simpress/main0107.html">Fenestro</a></li>\
    <li><a target="_top" href="eo/text/shared/main0108.html">Helpo</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020202"><label for="04020202">Ilobretoj</label><ul>\
    <li><a target="_top" href="eo/text/sdraw/main0200.html">Ilobretoj</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0210.html">Desegna breto</a></li>\
    <li><a target="_top" href="eo/text/sdraw/main0213.html">Agorda breto</a></li>\
    <li><a target="_top" href="eo/text/shared/main0201.html">Ĝenerala breto</a></li>\
    <li><a target="_top" href="eo/text/shared/main0213.html">Ilbreto por navigi formularojn</a></li>\
    <li><a target="_top" href="eo/text/shared/main0226.html">Ilbreto por aranĝi formularon</a></li>\
    <li><a target="_top" href="eo/text/shared/main0227.html">Ilbreto Redakti punktojn</a></li>\
                 </ul></li>\
             </ul></li>\
         </ul></li>\
    <li><input type="checkbox" id="0403"><label for="0403">Ŝargi, konservi, importi kaj eksporti</label><ul>\
    <li><a target="_top" href="eo/text/simpress/guide/html_export.html">Saving a Presentation in HTML Format</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/html_import.html">Importing HTML Pages Into Presentations</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/palette_files.html">Loading Color, Gradient, and Hatching Lists</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/animated_gif_save.html">Eksportado de animacioj en GIF-formato</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/table_insert.html">Including Spreadsheets in Slides</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/graphic_insert.html">Enmeti grafikaĵojn</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/page_copy.html">Copying Slides From Other Presentations</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0404"><label for="0404">Aranĝado</label><ul>\
    <li><a target="_top" href="eo/text/simpress/guide/palette_files.html">Loading Color, Gradient, and Hatching Lists</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/line_arrow_styles.html">Ŝargi liniajn kaj sagajn stilojn</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/color_define.html">Defining Custom Colors</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/gradient.html">Creating Gradient Fills</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/eyedropper.html">Replacing Colors</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/align_arrange.html">Arranging, Aligning and Distributing Objects</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/background.html">Changing the Slide Background Fill</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/footer.html">Aldoni paĝokapon aŭ paĝopiedon al ĉiuj lumbildoj</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/masterpage.html">Applying a Slide Design to a Master Slide</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/move_object.html">Moving Objects</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0405"><label for="0405">Presado</label><ul>\
    <li><a target="_top" href="eo/text/simpress/guide/printing.html">Printing Presentations</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/print_tofit.html">Presi lumbildon adapti al papergrando</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0406"><label for="0406">Efektoj</label><ul>\
    <li><a target="_top" href="eo/text/simpress/guide/animated_gif_save.html">Eksportado de animacioj en GIF-formato</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/animated_objects.html">Animating Objects in Presentation Slides</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/animated_slidechange.html">Animating Slide Transitions</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/cross_fading.html">Cross-Fading Two Objects</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/animated_gif_create.html">Krei GIF-movbildojn</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0407"><label for="0407">Objektoj, grafikoj, kaj bitbildoj</label><ul>\
    <li><a target="_top" href="eo/text/sdraw/guide/combine_etc.html">Kombini objektojn kaj konstrui formojn</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/draw_sector.html">Drawing Sectors and Segments</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/duplicate_object.html">Duplicating Objects</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/rotate_object.html">Rotating Objects</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/join_objects3d.html">Assembling 3D Objects</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/join_objects.html">Connecting Lines</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/text2curve.html">Converting Text Characters into Drawing Objects</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/vectorize.html">Converting Bitmap Images into Vector Graphics</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/3d_create.html">Konverstas 2D-objektojn al kurboj, plurlateroj, kaj 3D-objektoj</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/line_arrow_styles.html">Ŝargi liniajn kaj sagajn stilojn</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/line_draw.html">Desegni kurbojn</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/line_edit.html">Editing Curves</a></li>\
    <li><a target="_top" href="eo/text/sdraw/guide/graphic_insert.html">Enmeti grafikaĵojn</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/table_insert.html">Including Spreadsheets in Slides</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/move_object.html">Moving Objects</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/select_object.html">Selecting Underlying Objects</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/orgchart.html">Creating a Flowchart</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0408"><label for="0408">Grupoj kaj tavoloj</label><ul>\
    <li><a target="_top" href="eo/text/sdraw/guide/groups.html">Grouping Objects</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/layers.html">About Layers</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/layer_new.html">Inserting Layers</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/layer_tipps.html">Working With Layers</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/layer_move.html">Movi objektojn al alia tavolo</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0409"><label for="0409">Teksto en prezentaĵoj kaj desegnaĵoj</label><ul>\
    <li><a target="_top" href="eo/text/sdraw/guide/text_enter.html">Adding Text</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/text2curve.html">Converting Text Characters into Drawing Objects</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0410"><label for="0410">Vidoj</label><ul>\
    <li><a target="_top" href="eo/text/simpress/guide/arrange_slides.html">Ŝanĝi la ordon de lumbildoj</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/change_scale.html">Zooming With the Keypad</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0411"><label for="0411">Vidigi prezentaĵon</label><ul>\
    <li><a target="_top" href="eo/text/simpress/guide/show.html">Showing a Slide Show</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/presenter_console.html">Using the Presenter Console</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/impress_remote.html">Impress Remote Guide</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/individual.html">Creating a Custom Slide Show</a></li>\
    <li><a target="_top" href="eo/text/simpress/guide/rehearse_timings.html">Rehearse Timings of Slide Changes</a></li>\
         </ul></li>\
     </ul></li></ul>\
    <ul><li><input type="checkbox" id="03"><label for="03">Formulas (Math)</label><ul>\
    <li><input type="checkbox" id="0301"><label for="0301">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
    <li><a target="_top" href="eo/text/smath/main0000.html">Bonvenon al la Helpo de LibreOffice-Formulilo</a></li>\
    <li><a target="_top" href="eo/text/smath/main0503.html">Ebloj de LibreOffice-Formulilo</a></li>\
    <li><a target="_top" href="eo/text/smath/guide/main.html">Instructions for Using LibreOffice Math</a></li>\
    <li><a target="_top" href="eo/text/smath/guide/keyboard.html">Shortcuts (LibreOffice Math Accessibility)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0302"><label for="0302">Referenco pri ordonoj kaj menuoj</label><ul>\
    <li><a target="_top" href="eo/text/smath/main0100.html">Menuoj</a></li>\
    <li><a target="_top" href="eo/text/smath/main0200.html">Ilobretoj</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0303"><label for="0303">Labori per formuloj</label><ul>\
    <li><a target="_top" href="eo/text/smath/guide/align.html">Manually Aligning Formula Parts</a></li>\
    <li><a target="_top" href="eo/text/smath/guide/attributes.html">Changing Default Attributes</a></li>\
    <li><a target="_top" href="eo/text/smath/guide/brackets.html">Merging Formula Parts in Brackets</a></li>\
    <li><a target="_top" href="eo/text/smath/guide/comment.html">Entering Comments</a></li>\
    <li><a target="_top" href="eo/text/smath/guide/newline.html">Entering Line Breaks</a></li>\
    <li><a target="_top" href="eo/text/smath/guide/parentheses.html">Inserting Brackets</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="02"><label for="02">Text Documents (Writer)</label><ul>\
    <li><input type="checkbox" id="0201"><label for="0201">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
    <li><a target="_top" href="eo/text/swriter/main0000.html">Bonvenon al la helpo de LibreOffice-Verkilo</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0503.html">Ebloj de LibreOffice Verkilo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/main.html">Instrukcioj por uzi LibreOffice Verkilon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/resize_navigator.html">Doki kaj regrandigi fenestrojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/04/01020000.html">Fulmoklavoj por LibreOffice-Verkilo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/words_count.html">Nombrado de vortoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/keyboard.html">Uzi fulmoklavojn (LibreOffice Verkilo Alireblo)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0202"><label for="0202">Referenco pri ordonoj kaj menuoj</label><ul>\
    <li><input type="checkbox" id="020201"><label for="020201">Menuoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/main0100.html">Menuoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0101.html">Dosiero</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0102.html">Redakti</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0103.html">Vido</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0104.html">Enmeti</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0105.html">Formato</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0115.html">Stiloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0110.html">Tabelo</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0120.html">Formulara menuo</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0106.html">Iloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0107.html">Fenestro</a></li>\
    <li><a target="_top" href="eo/text/shared/main0108.html">Helpo</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="020202"><label for="020202">Ilobretoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/main0200.html">Ilobretoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0202.html">Formata breto</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0203.html">Bilda breto</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0204.html">Tabela breto</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0205.html">Breto de desegnaj objektaj atributoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0206.html">Breto por buloj kaj numerado</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0208.html">Stata breto</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0210.html">Aspekto de paĝo</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0213.html">Mezuriloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0214.html">Formula breto</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0215.html">Kadra breto</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0216.html">OLE-objekta breto</a></li>\
    <li><a target="_top" href="eo/text/swriter/main0220.html">Tekstobjekta breto</a></li>\
    <li><a target="_top" href="eo/text/shared/main0201.html">Ĝenerala breto</a></li>\
    <li><a target="_top" href="eo/text/shared/main0212.html">Ilbreto Tabelaj datumoj</a></li>\
    <li><a target="_top" href="eo/text/shared/main0213.html">Ilbreto por navigi formularojn</a></li>\
    <li><a target="_top" href="eo/text/shared/main0214.html">Ilbreto Fasoni informpeton</a></li>\
    <li><a target="_top" href="eo/text/shared/main0226.html">Ilbreto por aranĝi formularon</a></li>\
    <li><a target="_top" href="eo/text/swriter/librelogo/LibreLogo.html">LibreLogo-ilbreto</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0203"><label for="0203">Krei tekstajn dokumentojn</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/text_nav_keyb.html">Navigi kaj elekti per la klavaro</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/text_direct_cursor.html">Uzado de la rekta kursoro</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0204"><label for="0204">Grafikoj en tekstaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_graphic.html">Enmeti grafikaĵojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_graphic_dialog.html">Enmeti bildon el dosiero</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_graphic_gallery.html">Enmeti bildojn el la Galerio per ŝovo kaj demeto</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_graphic_scan.html">Enmeti skanitan bildon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_graphic_fromchart.html">Enmeti diagramon el Kalkulio en tekstan dokumenton</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_graphic_fromdraw.html">Enmeti bildon de LibreOffice Desegnilo aŭ Prezentilo</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0205"><label for="0205">Tabeloj en tekstaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/number_date_conv.html">Ŝalti/malŝalti rekonon de numeroj en tabeloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/tablemode.html">Modifi vicojn kaj kolumnojn per klavaro</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/table_delete.html">Forigi tabelojn aŭ la enhavon de tabelo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/table_insert.html">Enmeti tabelojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/table_repeat_multiple_headers.html">Ripeti tabelan titolon ĉe nova paĝo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/table_sizing.html">Regrandigi vicojn kaj kolumnojn en teksta tabelo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/table_cells.html">Aldoni aŭ forigi vicon aŭ kolumnon en tabelo uzante la klavaron.</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0206"><label for="0206">Objektoj en tekstaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/anchor_object.html">Lokado de objektoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/wrap.html">Ĉirkaŭfluado de teksto ĉirkaŭ objektoj</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0207"><label for="0207">Sekcioj kaj kadroj en tekstaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/sections.html">Uzi sekciojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/text_frame.html">Enmetado, redaktado kaj ligado de tekstaj kadroj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/section_edit.html">Redakti sekciojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/section_insert.html">Enmeti sekciojn</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0208"><label for="0208">Tabeloj de enhavo kaj indeksoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/chapter_numbering.html">Ĉapitra numerado</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_userdef.html">Propre difinitaj indeksoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_toc.html">Krei tabelon de enhavo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_index.html">Krei alfabetajn indeksojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_multidoc.html">Indeksoj kiuj kovras plurajn dokumentojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_literature.html">Krei bibliografion</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_delete.html">Redakti aŭ forigi indeksajn kaj tabelajn elementojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_edit.html">Ĝisdatigi, redakti kaj forigi indeksojn kaj tabelojn de enhavo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_enter.html">Difini indekson aŭ erojn de tabelo de enhavo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/indices_form.html">Formati indekson aŭ tabelon de enhavo</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0209"><label for="0209">Kampoj en tekstaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/fields.html">Pri kampoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/fields_date.html">Enmeti fiksitan aŭ variablan datan kampon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/field_convert.html">Konverti kampon al teksto</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0210"><label for="0210">Navigi en tekstaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/dragdroptext.html">Movi kaj kopii tekston en dokumentoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/arrange_chapters.html">Rearanĝi dokumenton uzante la Navigilon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/hyperlinks.html">Enmeti hiperligilojn per la Navigilo.</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/navigator.html">Navigilo por tekstaj dokumentoj</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0211"><label for="0211">Kalkuli en tekstaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/calculate_multitable.html">Kalkuli trans tabeloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/calculate.html">Kalkuli en tekstaj dokumentoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/calculate_clipboard.html">Kalkuli kaj alglui la rezulton de formulo en tekstan dokumenton</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/calculate_intable.html">Kalkuli ĉelajn sumojn en tabeloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/calculate_intext.html">Kalkuli komplikajn formulojn en tekstaj dokumentoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/calculate_intext2.html">Vidigi la rezulton de tabela kalkulo en alia tabelo.</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0212"><label for="0212">Formati tekstajn dokumentojn</label><ul>\
    <li><input type="checkbox" id="021201"><label for="021201">Ŝablonoj kaj stiloj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/templates_styles.html">Ŝablonoj kaj stiloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/even_odd_sdw.html">Alternantaj paĝaj stiloj ĉe paraj kaj malparaj paĝoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/change_header.html">Krei paĝan stilon bazitan sur la aktuala paĝo.</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/load_styles.html">Uzi stilojn el alia dokumento aŭ ŝablono</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/stylist_fromselect.html">Krei novajn stilojn el elektaĵoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/stylist_update.html">Ĝisdatigi stilojn el elektaĵoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/template_create.html">Krei dokumentan ŝablonon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/template_default.html">Ŝanĝi la aprioran ŝablonon</a></li>\
			</ul></li>\
    <li><a target="_top" href="eo/text/swriter/guide/pageorientation.html">Ŝanĝi paĝan orientiĝon (Horizontala aŭ vertikala)</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/text_capital.html">Ŝanĝi la usklecon deteksto</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/hidden_text.html">Kaŝi tekston</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/header_pagestyles.html">Difini malsamajn paĝokapojn kaj paĝopiedojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/header_with_chapter.html">Enmeti ĉapitran nomon kaj numeron en paĝokapon aŭ paĝopiedon.</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/shortcut_writing.html">Apliki tekstan formaton dum tajpado</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/reset_format.html">Reagordi tiparajn atributojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/stylist_fillformat.html">Apliki stilojn en reĝimo pleniga formato</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/wrap.html">Ĉirkaŭfluado de teksto ĉirkaŭ objektoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/text_centervert.html">Uzi kadron por centrigi tekston en paĝo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/text_emphasize.html">Emfazado de teksto</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/text_rotate.html">Turnado de teksto</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/page_break.html">Enmeti kaj forigi paĝajn saltojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/pagestyles.html">Krei kaj apliki paĝajn stilojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/subscript.html">Igi tekston alta skribo aŭ malalta skribo</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0213"><label for="0213">Specialaj tekstaj elementoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/captions.html">Uzi apudskribojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/conditional_text.html">Kondiĉa teksto</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/conditional_text2.html">Kondiĉa teksto por nombro da paĝaj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/fields_date.html">Enmeti fiksitan aŭ variablan datan kampon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/fields_enter.html">Aldoni enmetajn kampojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/footer_nextpage.html">Enmeti paĝajn numerojn de daŭrigaj paĝoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/footer_pagenumber.html">Enmeti paĝajn numerojn en paĝopiedojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/hidden_text.html">Kaŝi tekston</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/header_pagestyles.html">Difini malsamajn paĝokapojn kaj paĝopiedojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/header_with_chapter.html">Enmeti ĉapitran nomon kaj numeron en paĝokapon aŭ paĝopiedon.</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/fields_userdata.html">Informpeti pri propraj datumoj en kampoj aŭ kondiĉoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/footnote_usage.html">Enmeti kaj redakti piednotojn aŭ finnotojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/footnote_with_line.html">Interspacoj inter piednotoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/header_footer.html">Pri paĝokapoj kaj paĝopiedoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/header_with_line.html">Formati paĝokapojn aŭ paĝopiedojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/text_animation.html">Animacii tekston</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/form_letters_main.html">Krei ĉefan leteron</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0214"><label for="0214">Aŭtomataj funkcioj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/autocorr_except.html">Aldoni esceptojn al la listo Aŭtomate korekti</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/autotext.html">Uzi AŭtomataTekston</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/auto_numbering.html">Krei numeritajn aŭ bulajn listojn dum tajpado</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/auto_off.html">Malŝalti Aŭtomatan korektadon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/auto_spellcheck.html">Aŭtomate kontroli literumadon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/number_date_conv.html">Ŝalti/malŝalti rekonon de numeroj en tabeloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/using_hyphen.html">Vortdivido</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0215"><label for="0215">Numerado kaj listoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/captions_numbers.html">Aldoni ĉapitrajn nombrojn al apudskriboj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/auto_numbering.html">Krei numeritajn aŭ bulajn listojn dum tajpado</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/chapter_numbering.html">Ĉapitra numerado</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_tab_innumbering.html">Ŝanĝi la skeman nivelon de numeraj kaj bulaj listoj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/join_numbered_lists.html">Kombini numerajn listojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/numbering_lines.html">Enmeti liniajn numerojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/numbering_paras.html">Modifi numeradon en numera listo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/number_sequence.html">Difini numerajn ampleksojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/using_numbered_lists2.html">Aldonado de numerado</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/using_numbering.html">Numerado kaj numeradaj stiloj</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/using_numbered_lists.html">Aldonado de buloj</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0216"><label for="0216">Literumada kontrolo, tezaŭro, kaj lingvoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/auto_spellcheck.html">Aŭtomate kontroli literumadon</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/delete_from_dict.html">Forigi vortojn el propre difinita vortaro</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/using_thesaurus.html">Tezaŭro</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/spellcheck_dialog.html">Kontroli literumadon kaj gramatikon</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0218"><label for="0218">Problemsolvaj konsiletoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/insert_beforetable.html">Enmeti tekston antaŭ tabelo ĉe la supro de paĝo</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/jump2statusbar.html">Iri al specifa legosigno</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0219"><label for="0219">Ŝargi, konservi, importi kaj eksporti</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/send2html.html">Konservi tekstajn dokumentojn en HTML-formato</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/textdoc_inframe.html">Enmeti tutan tekstdokumenton</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0220"><label for="0220">Ĉefaj dokumentoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/globaldoc.html">Ĉefaj Dokumentoj kaj Subdokumentoj</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0221"><label for="0221">Ligiloj kaj referencoj</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/references.html">Enmeti krucreferencojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/hyperlinks.html">Enmeti hiperligilojn per la Navigilo.</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0222"><label for="0222">Presado</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/printer_tray.html">Elekti presilajn paperajn pletojn</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/print_preview.html">Aspekto antaŭ presado</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/print_small.html">Presi plurajn paĝojn sur unu folio.</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/pagestyles.html">Krei kaj apliki paĝajn stilojn</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0223"><label for="0223">Serĉi kaj anstataŭigi</label><ul>\
    <li><a target="_top" href="eo/text/swriter/guide/search_regexp.html">Uzi ĵokerojn en tekstserĉoj</a></li>\
    <li><a target="_top" href="eo/text/shared/01/02100001.html">List of Regular Expressions</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="06"><label for="06">HTML Documents (Writer Web)</label><ul>\
    <li><a target="_top" href="eo/text/shared/07/09000000.html">TTT-paĝoj</a></li>\
    <li><a target="_top" href="eo/text/shared/02/01170700.html">HTML Filters and Forms</a></li>\
    <li><a target="_top" href="eo/text/swriter/guide/send2html.html">Konservi tekstajn dokumentojn en HTML-formato</a></li>\
	</ul></li></ul>\
';
